<?php

namespace Litecms\Company\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Litecms\Company\Http\Resources\CompanyResource;
use Litecms\Company\Http\Resources\CompaniesCollection;
use Litecms\Company\Scopes\YearPublicScope;
use Litecms\Company\Models\Year;

class YearPublicController extends BaseController
{

    /**
     * Show year's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Year::pushScope(new RequestScope())
            ->pushScope(new YearPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $years = new YearsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('company::year.names'))
            ->view('company::public.year.index')
            ->data(compact('years', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show year.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Year::findBySlug($slug);
        $data = new YearResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('company::year.name'))
            ->view('company::public.year.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
