<?php

namespace Litecms\Company\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Company\Events\YearAction as YearActionEvent;
use Litecms\Company\Notifications\YearAction as YearActionNotification;
use Litepie\Actions\Concerns\AsAction;

class YearAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the YearActionEvent.
     *
     * @param   YearActionEvent  $event
     * @return mixed
     */
    public function handle(YearActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $year.
     *
     * @param   YearActionEvent  $event
     * @return void
     */
    public function create(YearActionEvent $event)
    {
        $client = $event->year->client;
        Notification::send($client, new YearActionNotification($event));
    }

    /**
     * Handle the YearActionEvent as a listener.
     *
     * @param   YearActionEvent  $event
     * @return mixed
     */
    public function asListener(YearActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   YearActionEvent  $event
     * @return bool
     */
    private function isAllowed(YearActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
