<?php

namespace Litecms\Company\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Litecms\Company\Models\Year;

class YearPolicy
{

    use YearAction;

    /**
     * Determine if the given user can view the year.
     *
     * @param Authenticatable $user
     * @param Year $year
     *
     * @return bool
     */
    public function view(Authenticatable $user, Year $year)
    {
        if ($authUser->canDo('company.year.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $year->is_owner;
    }

    /**
     * Determine if the given user can create a year.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('company.year.create');
    }

    /**
     * Determine if the given user can update the given year.
     *
     * @param Authenticatable $user
     * @param Year $year
     *
     * @return bool
     */
    public function update(Authenticatable $user, Year $year)
    {
        if ($user->canDo('company.year.edit') && $user->isAdmin()) {
            return true;
        }

        return $year->is_owner;
    }

    /**
     * Determine if the given user can delete the given year.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Year $year)
    {
        return $year->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
